
import { SGraphItem, SImageItem, SImageShowType } from "@saga-web/graph/lib";
import { SPainter } from "@saga-web/draw";
import { Marker } from '../types/Marker';

/**
 * 标识对象Item(图标类型)
 *
 * * @author  张宇(taohuzy@163.com)
 */
export class SImageMarkerItem extends SImageItem {
    /** 标识对象数据 */
    data: Marker;

    /**
     * 构造函数
     *
     * @param parent    指向父对象
     * @param data      标识对象数据
     */
    constructor(parent: SGraphItem | null, data: Marker) {
        super(parent);
        this.data = data;
        this.id = data.ID;
        this.name = data.Name;
        this.moveTo(data.Pos.X, data.Pos.Y);
        if (data.Size) {
            this.width = data.Size.Width;
            this.height = data.Size.Height;
        }
        if (data.Properties && data.Properties.Url) {
            this.url = data.Properties.Url;
        }
    } // Constructor

    toData(): Marker {
        this.data.Pos = {X: this.x, Y: this.y};
        this.data.Size = {Width: this.width, Height: this.height};
        this.data.Properties.Url = this.url;
        return this.data;
    }
} // Class SImageMarkerItem
